%define debug_package %{nil}

# Warning:
# Anyone editing this spec file please make sure the same spec file
# works on other fedora and epel releases, which are supported by this software.
# No quick Rawhide-only fixes will be allowed.

%global upstream_name libdaq

%if 0%{?el7}
# el7/{ppc64,ppc64le} Error: No Package found for libdnet-devel
ExclusiveArch:	x86_64 aarch64
%endif

Summary:	Data Acquisition Library
Name:		daq
Version:	3.0.9
Release:	1%{?dist}
# sfbpf is BSD (various versions)
License:	GPLv2 and BSD
URL:		https://www.snort.org
Source0:	https://www.snort.org/downloads/snort/%{upstream_name}-%{version}.tar.gz

BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	hwloc-devel
BuildRequires:	libdnet-devel
BuildRequires:	libmnl-devel
BuildRequires:	libnetfilter_queue-devel
BuildRequires:	libnfnetlink-devel
BuildRequires:	libpcap-devel
BuildRequires:	libtool
BuildRequires:	libunwind-devel
BuildRequires:	luajit-devel
BuildRequires:	openssl-devel
BuildRequires:	pcre-devel
BuildRequires:	pkgconfig
BuildRequires:	zlib-devel
Obsoletes:	daq < 3.0.0

# handle license on el{6,7}: global must be defined after the License field above
%{!?_licensedir: %global license %doc}


%description
Snort 2.9 introduces the DAQ, or Data Acquisition library, for packet I/O.  The
DAQ replaces direct calls to libpcap functions with an abstraction layer that
facilitates operation on a variety of hardware and software interfaces without
requiring changes to Snort.


%package modules
Summary:	Dynamic DAQ modules

%description modules
Dynamic DAQ modules.


%package devel
Summary:	Development libraries and headers for %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
Development libraries and headers for %{name}.


%prep
%autosetup -n %{upstream_name}-%{version}
autoreconf -ivf -Wobsolete


%build
%{configure}
# get rid of rpath
%{__sed} -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
%{__sed} -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%{__make}


%install
%{make_install}
# get rid of la files
find $RPM_BUILD_ROOT -type f -name "*.la" -delete -print

%if 0%{?fedora} >= 26
%ldconfig_scriptlets
%else
%post 
/sbin/ldconfig

%postun 
/sbin/ldconfig
%endif


%files
%{_libdir}/*
%doc ChangeLog-2.x README.md
%license COPYING


%files devel
%{_bindir}/*
%{_includedir}/*.h
%{_libdir}/*

%files modules
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*
%license COPYING

%changelog
* Wed Jun 15 2022 Lawrence R. Rogers <lrr@cert.org> - 3.0.9-1
- Releae 3.0.9-1
	DAQ 3.0.9 for Snort 3

* Thu Jun  2 2022 Lawrence R. Rogers <lrr@cert.org> - 3.0.8-1
- Releae 3.0.8-1
	DAQ 3.0.8 for Snort 3

* Wed May  4 2022 Lawrence R. Rogers <lrr@cert.org> - 3.0.7-1
- Releae 3.0.7-1
	DAQ 3.0.7 for Snort 3

* Tue Aug 24 2021 Lawrence R. Rogers <lrr@cert.org> - 3.0.5-1
- Releae 3.0.5-1
	DAQ 3.0.5 for Snort 3

* Sat Jun 19 2021 Lawrence R. Rogers <lrr@cert.org> - 3.0.4-1
- Releae 3.0.4-1
	DAQ 3.0.4 for Snort 3

* Mon May  3 2021 Lawrence R. Rogers <lrr@cert.org> - 3.0.3-1
- Releae 3.0.3-1
	DAQ 3.0.3 for Snort 3

* Wed Aug 12 2020 Lawrence R. Rogers <lrr@cert.org> - 3.0.0-1
- Releae 3.0.0-1
	DAQ 3.0.0 for Snort 3

* Mon Apr 13 2020 Lawrence R. Rogers <lrr@cert.org> - 2.0.7-10.1
- Releae 2.0.7-10.1
	Rebuilt for DAQ 2.0.8 and to add the static libraries
	The revision number is a guess to be a number higher than what Fedora or
		CentOS provide so as to install the static libraries needed for snort.

* Fri Nov  1 2019 Lawrence R. Rogers <lrr@cert.org> - 2.0.6-8.1
- Rebuilt to add the static libraries

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.6-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Nov 12 2016 Marcin Dulak <Marcin.Dulak@gmail.com> - 2.0.6-1
- initial version, based on Lawrence R. Rogers's daq.spec from forensics.cert.org
